<?php

namespace Drupal\commerce_funds\Plugin\Commerce\PaymentMethodType;

use Drupal\entity\BundleFieldDefinition;
use Drupal\commerce_payment\Entity\PaymentMethodInterface;
use Drupal\commerce_payment\Plugin\Commerce\PaymentMethodType\PaymentMethodTypeBase;

/**
 * Provides the Balance payment method type.
 *
 * @CommercePaymentMethodType(
 *   id = "funds_wallet",
 *   label = @Translation("Funds balance"),
 * )
 */
class BalanceMethodType extends PaymentMethodTypeBase {

  /**
   * {@inheritdoc}
   */
  public function buildLabel(PaymentMethodInterface $payment_method) {
    $args = [
      '@currency' => $payment_method->get('currency')->getValue()[0]['target_id'],
    ];

    return $this->t('Wallet (@currency)', $args);
  }

  /**
   * {@inheritdoc}
   */
  public function buildFieldDefinitions() {
    $fields['balance_id'] = BundleFieldDefinition::create('integer')
      ->setLabel(t('User balance'))
      ->setDescription(t('The balance id of the user.'))
      ->setRequired(TRUE);

    $fields['currency'] = BundleFieldDefinition::create('entity_reference')
      ->setLabel(t('Currency'))
      ->setDescription(t('The currency of the transaction.'))
      ->setSetting('target_type', 'commerce_currency')
      ->setRequired(TRUE);

    return $fields;
  }

}
